ipympl: Matplotlib Jupyter Extension
====================================

Description
-----------

Matplotlib Jupyter Extension

License
-------

BSD License

Upstream Contact
----------------

https://pypi.org/project/ipympl/

